# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettingsResponse(Model):
    """EnergyStarSettingsResponse.

    :param pm_account_manager_full_name: Full name of Portfolio Account
     Manager
    :type pm_account_manager_full_name: str
    :param pm_account_manager_user_name: User name of Portfolio Account
     Manager
    :type pm_account_manager_user_name: str
    :param notification_recipients: List of e-mail notification recipients
    :type notification_recipients: list[str]
    :param earliest_submission_period: The earliest period to submit
    :type earliest_submission_period: int
    """

    _attribute_map = {
        'pm_account_manager_full_name': {'key': 'pmAccountManagerFullName', 'type': 'str'},
        'pm_account_manager_user_name': {'key': 'pmAccountManagerUserName', 'type': 'str'},
        'notification_recipients': {'key': 'notificationRecipients', 'type': '[str]'},
        'earliest_submission_period': {'key': 'earliestSubmissionPeriod', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarSettingsResponse, self).__init__(**kwargs)
        self.pm_account_manager_full_name = kwargs.get('pm_account_manager_full_name', None)
        self.pm_account_manager_user_name = kwargs.get('pm_account_manager_user_name', None)
        self.notification_recipients = kwargs.get('notification_recipients', None)
        self.earliest_submission_period = kwargs.get('earliest_submission_period', None)
