# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UpdatedOnlyResult(Model):
    """UpdatedOnlyResult.

    :param updated:  <span class='property-internal'>Required (defined)</span>
    :type updated: int
    """

    _attribute_map = {
        'updated': {'key': 'updated', 'type': 'int'},
    }

    def __init__(self, *, updated: int=None, **kwargs) -> None:
        super(UpdatedOnlyResult, self).__init__(**kwargs)
        self.updated = updated
