# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillingPeriodUseCostDeltaChild(Model):
    """BillingPeriodUseCostDeltaChild.

    :param billing_period: The billing period that the data represents.
     Will be the current billing period, the same year prior billing period,
     or the same period prior year billing period.
    :type billing_period: int
    :param use:
    :type use: ~energycap.sdk.models.BillingPeriodUseUnitDeltaChild
    :param cost:
    :type cost: ~energycap.sdk.models.BillingPeriodCostUnitDeltaChild
    """

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'use': {'key': 'use', 'type': 'BillingPeriodUseUnitDeltaChild'},
        'cost': {'key': 'cost', 'type': 'BillingPeriodCostUnitDeltaChild'},
    }

    def __init__(self, **kwargs):
        super(BillingPeriodUseCostDeltaChild, self).__init__(**kwargs)
        self.billing_period = kwargs.get('billing_period', None)
        self.use = kwargs.get('use', None)
        self.cost = kwargs.get('cost', None)
